ResourcesSpec

Struct ResourcesSpec 

pub struct ResourcesSpec {
    pub cpu: Option<f64>,
    pub memory: Option<String>,
    pub gpu: Option<GpuSpec>,
    pub pids_limit: Option<i64>,
    pub cpuset: Option<String>,
    pub cpu_shares: Option<u32>,
    pub memory_swap: Option<String>,
    pub memory_reservation: Option<String>,
    pub memory_swappiness: Option<u8>,
    pub oom_score_adj: Option<i32>,
    pub oom_kill_disable: Option<bool>,
    pub blkio_weight: Option<u16>,
}
Resource limits (upper bounds, not reservations)

Fields

cpu: Option<f64>

CPU limit (cores, e.g., 0.5, 1, 2)

memory: Option<String>

Memory limit (e.g., “512Mi”, “1Gi”, “2Gi”)

gpu: Option<GpuSpec>

GPU resource request

pids_limit: Option<i64>

Maximum number of processes the container may spawn (Docker --pids-limit).

cpuset: Option<String>

CPUs that the container is allowed to execute on (Docker --cpuset-cpus).

cpu_shares: Option<u32>

Relative CPU shares (Docker --cpu-shares). Default weight is 1024.

memory_swap: Option<String>

Total memory limit including swap (Docker --memory-swap).

memory_reservation: Option<String>

Soft memory limit (Docker --memory-reservation).

memory_swappiness: Option<u8>

Container memory swappiness, 0-100 (Docker --memory-swappiness).

oom_score_adj: Option<i32>

OOM-killer score adjustment (Docker --oom-score-adj).

oom_kill_disable: Option<bool>

Disable the OOM killer for the container (Docker --oom-kill-disable).

blkio_weight: Option<u16>

Block IO weight, 10-1000 (Docker --blkio-weight).